@@ -24,8 +24,19 @@
 winsorZ <- function(x,
                     zbound = 3) {
   x <- as.numeric(as.character(x)) # convert to numeric just in case
-  z <- scale(x) # gives z-scores for vector x
-  x[!is.na(z) & z > zbound] <- max(x[!is.na(z) & z <= zbound])
-  x[!is.na(z) & z < (-1 * zbound)] <- min(x[!is.na(z) & z >= (-1 * zbound)])
+  z <- scale(x)[, 1] # gives z-scores for vector x
+
+  valid <- !is.na(z) & abs(z) <= zbound
+  if (sum(valid) == 0) {
+    warning("No valid values within z-score bounds")
+    return(x)
+  }
+  if (sum(!valid) == 0) {
+    warning("No outlies outside z-score bounds")
+    return(x)
+  }
+  bounds <- range(x[valid])
+  x[!is.na(z) & z > zbound] <- bounds[2]
+  x[!is.na(z) & z < -zbound] <- bounds[1]
   return(x)
 }
