@@ -20,8 +20,9 @@
 winsorZ_find <- function(x,
                          zbound = 3) {
   x <- as.numeric(as.character(x)) # convert to numeric just in case
-  z <- scale(x) # create z-scores for vector x
-  x[!is.na(z) & (z < zbound & z > (-1 * zbound))] <- 0
-  x[!is.na(z) & (z > zbound | z < (-1 * zbound))] <- 1
-  return(as.factor(x))
+  z <- scale(x)[, 1] # create z-scores for vector x
+  # 1 for outliers, 0 for non-outliers, NA stays NA
+  out <- ifelse(!is.na(z) & abs(z) > zbound, 1,
+                ifelse(!is.na(z), 0, NA))
+  return(as.factor(out))
 }
